@@ -62,7 +62,7 @@ MANIFEST_PATH = "target/manifest.json"
 PROJECT_FILE = "dbt_project.yml"
 PROFILES_FILE = "profiles.yml"
 LOWER_DBT_V = "1.0.0"
-UPPER_DBT_V = "1.6.0"
+UPPER_DBT_V = "1.7.0"
 
 
 # https://github.com/dbt-labs/dbt-core/blob/c952d44ec5c2506995fbad75320acbae49125d3d/core/dbt/cli/resolvers.py#L6
@@ -103,7 +103,6 @@ class DbtParser:
     ) -> None:
         try_set_dbt_flags()
         self.dbt_runner = try_get_dbt_runner()
-        self.profiles_dir = Path(profiles_dir_override or default_profiles_dir())
         self.project_dir = Path(project_dir_override or default_project_dir())
         self.connection = {}
         self.project_dict = self.get_project_dict()
@@ -119,6 +118,13 @@ class DbtParser:
         self.threads = None
         self.unique_columns = self.get_unique_columns()
 
+        if profiles_dir_override:
+            self.profiles_dir = Path(profiles_dir_override)
+        elif parse_version(self.dbt_version) < parse_version("1.3.0"):
+            self.profiles_dir = legacy_profiles_dir()
+        else:
+            self.profiles_dir = default_profiles_dir()
+
     def get_datadiff_config(self) -> TDatadiffConfig:
         data_diff_vars = self.project_dict.get("vars", {}).get("data_diff", {})
         prod_database = data_diff_vars.get("prod_database")
@@ -211,9 +217,6 @@ class DbtParser:
 
         dbt_version = parse_version(run_results_obj.metadata.dbt_version)
 
-        if dbt_version < parse_version("1.3.0"):
-            self.profiles_dir = legacy_profiles_dir()
-
         if dbt_version < parse_version(LOWER_DBT_V):
             raise DataDiffDbtRunResultsVersionError(
                 f"Found dbt: v{dbt_version} Expected the dbt project's version to be >= {LOWER_DBT_V}"
